#!/bin/bash

# Csound shell script

CSFLAGS="-d -m7 -H1 -J -b 4096 -B 4096"		# display off, heartbeat, IRCAM format, buffer=4096 samples

if ( ( [ $# != 1 ] ) && ( [ $# != 2 ] ) && ( [ $# != 3 ] ) ) ; then		# print usage

	echo -e "Usage:"
	echo -e "------"
	echo -e "cs.sh <fname>"
	echo -e " - renders fname.sf using fname.orc and fname.sco"
	echo -e "cs.sh <s|ms|f|mf> <fname>"
	echo -e " - s: short int output, f: float output, m: use midifile fname.mid"
	echo -e "cs.sh <s|ms|f|mf> <fname> <infile>"
	echo -e " - use infile as input file"
	exit 0					;

fi

MIDIFILE=""	# default: no MIDI file

if [ $# == 1 ] ; then			# only one parameter specified

	csound ${CSFLAGS} -f -o "${1}.sf" "${1}.orc" "${1}.sco" ;

else	case ${1} in			# there are two or more parameters

		(s)	CSFLAGS="${CSFLAGS} -s"			;;	# short int output
		(ms)	CSFLAGS="${CSFLAGS} -s" ; MIDIFILE="X"	;;	# short int output,MIDI file
		(f)	CSFLAGS="${CSFLAGS} -f"			;;	# float output
		(mf)	CSFLAGS="${CSFLAGS} -f" ; MIDIFILE="X"	;;	# float output,MIDI file
	esac

	if [ $# == 2 ] ; then

		if [ "${MIDIFILE}" != "" ] ; then

			csound ${CSFLAGS} -F "${2}.mid" -o "${2}.sf" "${2}.orc" "${2}.sco" ;
		else	csound ${CSFLAGS} -o "${2}.sf" "${2}.orc" "${2}.sco" ;
		fi ;
	else
		if [ "${MIDIFILE}" != "" ] ; then	# input file is specified

			csound ${CSFLAGS} -F "${2}.mid" -i "${3}" -o "${2}.sf" "${2}.orc" "${2}.sco" ;
		else	csound ${CSFLAGS} -i "${3}" -o "${2}.sf" "${2}.orc" "${2}.sco" ;
		fi ;
	fi ;
fi

# end of script


